/* tslint:disable */
/* eslint-disable */
/**
* Initialize the library
*/
export function init_x12_translate_wasm(): void;
/**
* Formats the given `edi` string into lines, separated by the segment delimiter.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @returns {string}
*/
export function format(x12: string): string;
/**
* Extracts metadata from the given edi file.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @returns {MetadataResult}
*/
export function metadata(x12: string): MetadataResult;
/**
* Generate a 997 acknowledgment for the given edi file.
* @param {string} x12
* @param {string} isa_control_number
* @param {string} gs_control_number
* @returns {string | undefined}
*/
export function ack(x12: string, isa_control_number: string, gs_control_number: string): string | undefined;
/**
*/
export enum Standard {
  X12,
}
export interface Span {
    start: number;
    end: number;
}

export interface Delimiters {
    segment: string;
    element: string;
    composite: string;
    repetition: string;
}

export interface MetadataResult {
    interchanges: Interchange[];
}

export interface Interchange {
    senderQualifier?: string;
    senderId?: string;
    receiverQualifier?: string;
    receiverId?: string;
    controlNumber?: number;
    standard: Standard;
    span: Span;
    delimiters: Delimiters | null;
    functionalGroups: FunctionalGroup[];
}

export interface FunctionalGroup {
    functionalIdentifierCode?: string;
    applicationSenderCode?: string;
    applicationReceiverCode?: string;
    controlNumber?: number;
    release?: string;
    span: Span;
    transactionSets: TransactionSet[];
}

export interface TransactionSet {
    id?: string;
    controlNumber?: number;
    span: Span;
}


export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly init_x12_translate_wasm: () => void;
  readonly format: (a: number, b: number) => void;
  readonly metadata: (a: number, b: number) => void;
  readonly ack: (a: number, b: number, c: number, d: number) => void;
  readonly __wbindgen_export_0: (a: number) => number;
  readonly __wbindgen_export_1: (a: number, b: number, c: number) => number;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_export_2: (a: number, b: number) => void;
  readonly __wbindgen_export_3: (a: number) => void;
  readonly __wbindgen_start: () => void;
}

export type SyncInitInput = BufferSource | WebAssembly.Module;
/**
* Instantiates the given `module`, which can either be bytes or
* a precompiled `WebAssembly.Module`.
*
* @param {SyncInitInput} module
*
* @returns {InitOutput}
*/
export function initSync(module: SyncInitInput): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
